@@ -10,7 +10,7 @@ use Term::ANSIColor ();
 use Path::Class qw( file dir );
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '1.89'; # VERSION
+our $VERSION = '1.90'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -96,7 +96,7 @@ sub configure
     }
     else
     {
-      $installer ||= 'MakeMaker';
+      $installer ||= 'Author::Plicease::MakeMaker';
       $self->add_plugins($installer);
     }
   };
@@ -267,7 +267,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 1.89
+version 1.90
 
 =head1 SYNOPSIS
 
@@ -329,7 +329,7 @@ This plugin bundle is mostly equivalent to
  [License]
  [ExecDir]
  [ShareDir]
- [MakeMaker]
+ [Author::Plicease::MakeMaker]
  [Manifest]
  [TestRelease]
  [PodWeaver]
